/*
 * Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved.
 */

/*************************************************
File name: check_uid.h
Author: zhoukangyu
Version: 1.0.0
Description:

主要功能：
UID唯一性检查库的头文件实现，主要功能为：
1.提供四个函数接口

软件包依赖关系分析：
UID唯一性检查库主要被shadow软件使用，用于检查用户ID的唯一性。

Date: 2025-03-06
Others: 无
Function List:
int init_uid_record()  // 初始化用户ID记录文件
int uid_used(uid_t uid)  // 检查用户ID是否在/etc/uid_list文件中存在
int insert_uid_log(char *name, uid_t uid) // 增加用户ID到/etc/uid_list文件中
int get_chkuid_state() // 获取/etc/chkuid_state文件中UID唯一性开关状态

History:
1. 2025-03-06 zhoukangyu 创建文件

*************************************************/

#ifndef KYLIN_CHECK_UID_H
#define KYLIN_CHECK_UID_H

#ifdef __cplusplus
extern "C" {
#endif


#include <sys/types.h>

int init_uid_record();

int uid_used(uid_t uid);

int insert_uid_log(char *name, uid_t uid);

int check_and_fix_uid_record_file(const char *filename);

/**
 * @brief 获取check uid state, configured in /etc/chkuid_state
 *
 * @return int 0 not check(off), 1 need check(on), default is 0
 */
int get_chkuid_state();
#ifdef __cplusplus
};
#endif

#endif

